@@ -562,53 +562,27 @@ class ActivityPub:
 
         logger.debug("ActivityPub.post_status(...) - using URL=%s", url)
 
-        if self.instance_type == INSTANCE_TYPE_TAKAHE:
-            json_data = {
-                "status": status,
-                "visibility": visibility,
-                "sensitive": sensitive,
-            }
-            if media_ids:
-                json_data["media_ids"] = media_ids
-            if spoiler_text:
-                json_data["spoiler_text"] = spoiler_text
-
-            async with self.session.post(
-                url=url,
-                headers=headers,
-                json=json_data,
-            ) as response:
-                self.__update_ratelimit(headers=response.headers)
-                await ActivityPub.__check_exception(response=response)
-                result = await response.json()
-                logger.debug(
-                    "ActivityPub.post_status - request_info:\n%s",
-                    response.request_info,
-                )
-
-        else:
-            form_data = aiohttp.FormData()
-            form_data.add_field(name="status", value=status)
-            form_data.add_field(name="visibility", value=visibility)
-            form_data.add_field(name="sensitive", value=sensitive)
-            if media_ids:
-                form_data.add_field(name="media_ids[]", value=media_ids)
-            if spoiler_text:
-                form_data.add_field(name="spoiler_text", value=spoiler_text)
-
-            async with self.session.post(
-                url=url,
-                headers=headers,
-                data=form_data,
-            ) as response:
-                self.__update_ratelimit(headers=response.headers)
-                await ActivityPub.__check_exception(response=response)
-                result = await response.json()
-                logger.debug(
-                    "ActivityPub.post_status - request_info:\n%s",
-                    response.request_info,
-                )
+        form_data = aiohttp.FormData()
+        form_data.add_field(name="status", value=status)
+        form_data.add_field(name="visibility", value=visibility)
+        form_data.add_field(name="sensitive", value=sensitive)
+        if media_ids:
+            form_data.add_field(name="media_ids[]", value=media_ids)
+        if spoiler_text:
+            form_data.add_field(name="spoiler_text", value=spoiler_text)
 
+        async with self.session.post(
+            url=url,
+            headers=headers,
+            data=form_data,
+        ) as response:
+            self.__update_ratelimit(headers=response.headers)
+            await ActivityPub.__check_exception(response=response)
+            result = await response.json()
+            logger.debug(
+                "ActivityPub.post_status - request_info:\n%s",
+                response.request_info,
+            )
         logger.debug(
             "ActivityPub.post_status -> result:\n%s",
             json.dumps(result, indent=4),
@@ -751,7 +725,13 @@ class ActivityPub:
         :type headers: Any
         """
         temp_ratelimit_limit = temp_ratelimit_remaining = temp_ratelimit_reset = None
-        if not self.instance_type == INSTANCE_TYPE_PLEROMA:
+
+        if self.instance_type in (INSTANCE_TYPE_TAKAHE, INSTANCE_TYPE_PLEROMA):
+            # Takahe and Pleroma do not seem to return rate limit headers.
+            # Default to 5 minute rate limit reset time
+            temp_ratelimit_reset = arrow.now().shift(minutes=+5)
+
+        else:
             temp_ratelimit_limit = headers.get("X-RateLimit-Limit")
             temp_ratelimit_remaining = headers.get("X-RateLimit-Remaining")
             temp_ratelimit_reset = headers.get("X-RateLimit-Reset")
